[system-tools-backends-clone] Fix SelfConfig



commit 7bde7d0939d0c4b483203d9ca3969c7e3eff66f8
Author: Milan Bouchet-Valat <nalimilan club fr>
Date:   Sun Jan 17 12:02:41 2010 +0100

    Fix SelfConfig
    
    We don't need to use a struct, since the whole message only holds this object. Update the parameters taken in set_self(), which were outdated.

 SelfConfig.pm  |    2 +-
 Users/Users.pm |    4 ++--
 2 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/SelfConfig.pm b/SelfConfig.pm
index 4ca751b..47d713c 100644
--- a/SelfConfig.pm
+++ b/SelfConfig.pm
@@ -30,7 +30,7 @@ my $OBJECT_NAME = "SelfConfig2";
 my $OBJECT_PATH = "$Utils::Backend::DBUS_PATH/$OBJECT_NAME";
 
 # user is only allowed to change his own GECOS fields, locale, location
-my $format = [ [ "struct", "uint32", [ "array", "string" ], "string", "string" ] ];
+my $format = [ "uint32", [ "array", "string" ], "string", "string" ];
 
 sub new
 {
diff --git a/Users/Users.pm b/Users/Users.pm
index ff5726c..5a00012 100644
--- a/Users/Users.pm
+++ b/Users/Users.pm
@@ -745,7 +745,7 @@ sub set_user
 
 sub set_self
 {
-  my ($uid, $old_passwd, $new_passwd, @comments) = @_;
+  my ($uid, @comments, $locale, $location) = @_;
   my ($users) = &get ();
 
   # Make backups manually, otherwise they don't get backed up.
@@ -760,7 +760,7 @@ sub set_self
       return;
     }
   }
   # TODO: change password
 }
 
 
@@ -760,7 +760,7 @@ sub set_self
     }
   }
-  # TODO: change password
+  # TODO: change locale and location
 }
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]